@@ -515,7 +515,7 @@ Phloat atan(Phloat p) {
     return Phloat(res);
 }
 
-void sincos(Phloat phi, Phloat *s, Phloat *c) {
+void p_sincos(Phloat phi, Phloat *s, Phloat *c) {
     bid128_sin(&s->val, &phi.val);
     bid128_cos(&c->val, &phi.val);
 }
@@ -598,7 +598,7 @@ Phloat expm1(Phloat p) {
     return Phloat(res);
 }
 
-Phloat gamma(Phloat p) {
+Phloat tgamma(Phloat p) {
     BID_UINT128 res;
     bid128_tgamma(&res, &p.val);
     return Phloat(res);
